WhisperLibrary class

Inheritance

Constructors

WhisperLibrary({String? libraryWhisperPath})
Check Out: https://www.youtube.com/@GENERAL_DEV

Properties

hashCode int
The hash code for this object.
no setterinherited
libraryWhisperPath String
Check Out: https://www.youtube.com/@GENERAL_DEV
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() FutureOr<void>
Check Out: https://www.youtube.com/@GENERAL_DEV
override
ensureInitialized() Future<void>
Check Out: https://www.youtube.com/@GENERAL_DEV
override
initialized() FutureOr<void>
Check Out: https://www.youtube.com/@GENERAL_DEV
override
isCrash() bool
Check Out: https://www.youtube.com/@GENERAL_DEV
override
isDeviceSupport() bool
Check Out: https://www.youtube.com/@GENERAL_DEV
override
loadWhisperModel({String openVinoEncoderDevice = "CPU", required String whisperModelPath, bool isUseGpu = false, int gpuDevice = 0}) bool
Check Out: https://www.youtube.com/@GENERAL_DEV
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
transcribeToJson({required dynamic fileWav, bool isTranslate = false, String language = "auto", int useCountThread = 0, int useCountProccecors = 0}) Future<Map>
Check Out: https://www.youtube.com/@GENERAL_DEV
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

ggmlLogCallbackFunction(int level, Pointer<Char> text, Pointer<Void> userData) → void
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer